@@ -842,6 +842,18 @@ class ProvPopTable(pd.DataFrame):
 
         return result
 
+    def get_pop_groups(self):
+        '''
+        Get self.__pop_sex and self.__pop_age, the names of sex and age
+        columns.
+
+        Usage
+        -----
+        `ProvPopTable.get_pop_groups()`
+        '''
+
+        return [self.__pop_sex, self.__pop_age]
+
     def set_comp_end(self, comps: List[str]):
         '''
         Specify the component(s) recorded at the end of the period.
@@ -1352,10 +1364,8 @@ def calculate_modifiable_in_comp(
                 modifiable_0 = min(leftover, modifiable_val_in_comp_0)
         else:
             modifiable_0 =\
-                modifiable_val_in_comp_0 +\
                 (abs_modifiable_val_in_pop_end // 2)
             modifiable_1 =\
-                modifiable_val_in_comp_1 +\
                 abs_modifiable_val_in_pop_end - modifiable_0
         modifiable = [modifiable_0, modifiable_1]
     else:
