@@ -508,9 +508,11 @@ def run3():
     print(poptbl.calculate_pop())
 
     result = poptbl.fix_issues(return_all_mods = True)
+
     pprint(result)
     try:
         print(result.calculate_pop())
     except:
         print(result[0].calculate_pop())
-    # return result
+    
+    return result
